==> dto-2.0.0-20200827.112933-498-sources.jar: org/jboss/pnc/client/patch/BuildConfigurationPatchBuilder.java <==
package org.jboss.pnc.client.patch;

import java.lang.Exception;
import java.lang.Object;
import java.lang.String;
import java.util.Collection;
import java.util.Map;
import org.jboss.pnc.dto.BuildConfiguration;
import org.jboss.pnc.dto.BuildConfigurationRef;
import org.jboss.pnc.dto.Environment;
import org.jboss.pnc.dto.ProductVersionRef;
import org.jboss.pnc.dto.ProjectRef;
import org.jboss.pnc.dto.SCMRepository;
import org.jboss.pnc.enums.BuildType;

public class BuildConfigurationPatchBuilder extends PatchBase<BuildConfigurationPatchBuilder, BuildConfiguration> {
  public BuildConfigurationPatchBuilder() {
    super(org.jboss.pnc.dto.BuildConfiguration.class);
  }

  public BuildConfigurationPatchBuilder replaceScmRepository(SCMRepository element) throws
      PatchBuilderException {
    try {
      return replace(element, "scmRepository");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceProject(ProjectRef element) throws
      PatchBuilderException {
    try {
      return replace(element, "project");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceEnvironment(Environment element) throws
      PatchBuilderException {
    try {
      return replace(element, "environment");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder addDependencies(Map<String, BuildConfigurationRef> elements)
      throws PatchBuilderException {
    try {
      return add(elements, "dependencies");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceDependencies(
      Map<String, BuildConfigurationRef> element) throws PatchBuilderException {
    try {
      return replace(element, "dependencies");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder removeDependencies(Collection<Object> keys) throws
      PatchBuilderException {
    try {
      return remove(keys, "dependencies");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceProductVersion(ProductVersionRef element) throws
      PatchBuilderException {
    try {
      return replace(element, "productVersion");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder addParameters(Map<String, String> elements) throws
      PatchBuilderException {
    try {
      return add(elements, "parameters");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder removeParameters(Collection<Object> keys) throws
      PatchBuilderException {
    try {
      return remove(keys, "parameters");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceParameters(Map<String, String> element) throws
      PatchBuilderException {
    try {
      return replace(element, "parameters");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceName(String element) throws PatchBuilderException {
    try {
      return replace(element, "name");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceDescription(String element) throws
      PatchBuilderException {
    try {
      return replace(element, "description");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceBuildScript(String element) throws
      PatchBuilderException {
    try {
      return replace(element, "buildScript");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceScmRevision(String element) throws
      PatchBuilderException {
    try {
      return replace(element, "scmRevision");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceBuildType(BuildType element) throws
      PatchBuilderException {
    try {
      return replace(element, "buildType");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }
}

==> dto-2.7.0-20240228.160018-64-sources.jar: org/jboss/pnc/client/patch/BuildConfigurationPatchBuilder.java <==
package org.jboss.pnc.client.patch;

import java.lang.Boolean;
import java.lang.Exception;
import java.lang.Object;
import java.lang.String;
import java.util.Collection;
import java.util.Map;
import org.jboss.pnc.dto.BuildConfiguration;
import org.jboss.pnc.dto.BuildConfigurationRef;
import org.jboss.pnc.dto.Environment;
import org.jboss.pnc.dto.ProductVersionRef;
import org.jboss.pnc.dto.ProjectRef;
import org.jboss.pnc.dto.SCMRepository;
import org.jboss.pnc.enums.BuildType;

public class BuildConfigurationPatchBuilder extends PatchBase<BuildConfigurationPatchBuilder, BuildConfiguration> {
  public BuildConfigurationPatchBuilder() {
    super(org.jboss.pnc.dto.BuildConfiguration.class);
  }

  public BuildConfigurationPatchBuilder replaceScmRepository(SCMRepository element) throws
      PatchBuilderException {
    try {
      return replace(element, "scmRepository");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceProject(ProjectRef element) throws
      PatchBuilderException {
    try {
      return replace(element, "project");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceEnvironment(Environment element) throws
      PatchBuilderException {
    try {
      return replace(element, "environment");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder addDependencies(Map<String, BuildConfigurationRef> elements)
      throws PatchBuilderException {
    try {
      return add(elements, "dependencies");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceDependencies(
      Map<String, BuildConfigurationRef> element) throws PatchBuilderException {
    try {
      return replace(element, "dependencies");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder removeDependencies(Collection<Object> keys) throws
      PatchBuilderException {
    try {
      return remove(keys, "dependencies");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceProductVersion(ProductVersionRef element) throws
      PatchBuilderException {
    try {
      return replace(element, "productVersion");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder addParameters(Map<String, String> elements) throws
      PatchBuilderException {
    try {
      return add(elements, "parameters");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder removeParameters(Collection<Object> keys) throws
      PatchBuilderException {
    try {
      return remove(keys, "parameters");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceParameters(Map<String, String> element) throws
      PatchBuilderException {
    try {
      return replace(element, "parameters");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceName(String element) throws PatchBuilderException {
    try {
      return replace(element, "name");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceDescription(String element) throws
      PatchBuilderException {
    try {
      return replace(element, "description");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceBuildScript(String element) throws
      PatchBuilderException {
    try {
      return replace(element, "buildScript");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceScmRevision(String element) throws
      PatchBuilderException {
    try {
      return replace(element, "scmRevision");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceBuildType(BuildType element) throws
      PatchBuilderException {
    try {
      return replace(element, "buildType");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }

  public BuildConfigurationPatchBuilder replaceBrewPullActive(Boolean element) throws
      PatchBuilderException {
    try {
      return replace(element, "brewPullActive");
    } catch (Exception e) {
      throw new PatchBuilderException("Error creating patch.", e);
    }
  }
}
